@@ -7,8 +7,10 @@ import types
 
 import yaml
 
-from .settings_base import Settings
-from dotenv import load_dotenv
+from dotenv import dotenv_values
+from types import SimpleNamespace
+
+
 
 FILE_YAML = "settings.yaml"
 FILE_MODE = "config/mode.json"
@@ -65,10 +67,8 @@ def load_mode():
 def load_env(mode: str = None):
     """Load <Dot.Env> File"""
     active_env = LOAD_ENVS(mode) if mode else FILE_ENVS
-    env_settings = Settings(_env_file=active_env)
-    print(env_settings)
-    print(load_dotenv(LOAD_ENVS(mode)))
-    return env_settings
+    config = dotenv_values(active_env)
+    return SimpleNamespace(**{key.lower() : val for key, val in config.items()})
 
 
 def load_docs():
